@@ -1,5 +1,4 @@
-cl.memb.H <-
-function(U)
+cl.memb.H <- function(U)
 {
 if (missing(U))
 stop("The membership degree matrix U must be given")
@@ -8,7 +7,7 @@ stop("The membership degree matrix U is empty")
 U=as.matrix(U)
 if (any(is.na(U)))
 stop("The membership degree matrix U must not contain NA values")
-if (!is.numeric(U)) 
+if (!is.numeric(U))
 stop("The membership degree matrix U must be numeric")
 n=nrow(U)
 info.U=cbind(max.col(U),apply(U,1,max))
